==> iReport-nb-3.1.0-src.zip: iReport-nb-3.1.0-src/jasperserver-plugin/src/com/jaspersoft/ireport/jasperserver/ui/wizards/ReportUnitWizardPanel1.java <==
/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
package com.jaspersoft.ireport.jasperserver.ui.wizards;

import java.util.HashSet;
import java.util.Iterator;
import java.util.Set;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;
import org.openide.WizardDescriptor;
import org.openide.util.HelpCtx;

public class ReportUnitWizardPanel1 implements WizardDescriptor.Panel {

    private ReportUnitWizardDescriptor wizardDescriptor = null;
    
    public ReportUnitWizardPanel1(ReportUnitWizardDescriptor descriptor)
    {
        super();
        this.wizardDescriptor = descriptor;
    }
    
    public ReportUnitWizardDescriptor getWizardDescriptor() {
        return wizardDescriptor;
    }

    public void setWizardDescriptor(ReportUnitWizardDescriptor wizardDescriptor) {
        this.wizardDescriptor = wizardDescriptor;
    }
    
    
    /**
     * The visual component that displays this panel. If you need to access the
     * component from this class, just use getComponent().
     */
    private ReportUnitVisualPanel1 component;

    // Get the visual component for the panel. In this template, the component
    // is kept separate. This can be more efficient: if the wizard is created
    // but never displayed, or not all panels are displayed, it is better to
    // create only those which really need to be visible.
    public ReportUnitVisualPanel1 getComponent() {
        if (component == null) {
            component = new ReportUnitVisualPanel1(this);
        }
        return component;
    }

    public HelpCtx getHelp() {
        // Show no Help button for this panel:
        return HelpCtx.DEFAULT_HELP;
    // If you have context help:
    // return new HelpCtx(SampleWizardPanel1.class);
    }

    public boolean isValid() {
       try {
            component.validateForm();
            getWizardDescriptor().putProperty("WizardPanel_errorMessage", null);
            return true;
        } catch (Exception ex)
        {
            getWizardDescriptor().putProperty("WizardPanel_errorMessage", ex.getMessage());
        }
        return false;
    }

    private final Set<ChangeListener> listeners = new HashSet<ChangeListener>(1); // or can use ChangeSupport in NB 6.0
    
    public final void addChangeListener(ChangeListener l) {
        synchronized (listeners) {
            listeners.add(l);
        }
    }
    public final void removeChangeListener(ChangeListener l) {
        synchronized (listeners) {
            listeners.remove(l);
        }
    }
    protected final void fireChangeEvent() {
        Iterator<ChangeListener> it;
        synchronized (listeners) {
            it = new HashSet<ChangeListener>(listeners).iterator();
        }
        ChangeEvent ev = new ChangeEvent(this);
        while (it.hasNext()) {
            it.next().stateChanged(ev);
        }
    }
    

    // You can use a settings object to keep track of state. Normally the
    // settings object will be the WizardDescriptor, so you can use
    // WizardDescriptor.getProperty & putProperty to store information entered
    // by the user.
    public void readSettings(Object settings) {
        
    }

    public void storeSettings(Object settings) {
        getComponent().storeSettings(getWizardDescriptor());
        java.util.Iterator namesProps = getWizardDescriptor().getProperties().keySet().iterator();
        while (namesProps.hasNext())
        {
            String name = ""+namesProps.next();
            System.out.println("Property: " + name + " " + getWizardDescriptor().getProperty(name));
            System.out.flush();
        }
    }

}

==> iReport-nb-3.5.3-src.zip: iReport-nb-3.5.3-src/jasperserver-plugin/src/com/jaspersoft/ireport/jasperserver/ui/wizards/ReportUnitWizardPanel1.java <==
/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
package com.jaspersoft.ireport.jasperserver.ui.wizards;

import java.util.HashSet;
import java.util.Iterator;
import java.util.Set;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;
import org.openide.WizardDescriptor;
import org.openide.util.HelpCtx;

public class ReportUnitWizardPanel1 implements WizardDescriptor.Panel {

    private ReportUnitWizardDescriptor wizardDescriptor = null;
    
    public ReportUnitWizardPanel1(ReportUnitWizardDescriptor descriptor)
    {
        super();
        this.wizardDescriptor = descriptor;
    }
    
    public ReportUnitWizardDescriptor getWizardDescriptor() {
        return wizardDescriptor;
    }

    public void setWizardDescriptor(ReportUnitWizardDescriptor wizardDescriptor) {
        this.wizardDescriptor = wizardDescriptor;
    }
    
    
    /**
     * The visual component that displays this panel. If you need to access the
     * component from this class, just use getComponent().
     */
    private ReportUnitVisualPanel1 component;

    // Get the visual component for the panel. In this template, the component
    // is kept separate. This can be more efficient: if the wizard is created
    // but never displayed, or not all panels are displayed, it is better to
    // create only those which really need to be visible.
    public ReportUnitVisualPanel1 getComponent() {
        if (component == null) {
            component = new ReportUnitVisualPanel1(this);
        }
        return component;
    }

    public HelpCtx getHelp() {
        // Show no Help button for this panel:
        return HelpCtx.DEFAULT_HELP;
    // If you have context help:
    // return new HelpCtx(SampleWizardPanel1.class);
    }

    public boolean isValid() {
       try {
            component.validateForm();
            getWizardDescriptor().putProperty("WizardPanel_errorMessage", null);
            return true;
        } catch (Exception ex)
        {
            getWizardDescriptor().putProperty("WizardPanel_errorMessage", ex.getMessage());
        }
        return false;
    }

    private final Set<ChangeListener> listeners = new HashSet<ChangeListener>(1); // or can use ChangeSupport in NB 6.0
    
    public final void addChangeListener(ChangeListener l) {
        synchronized (listeners) {
            listeners.add(l);
        }
    }
    public final void removeChangeListener(ChangeListener l) {
        synchronized (listeners) {
            listeners.remove(l);
        }
    }
    protected final void fireChangeEvent() {
        Iterator<ChangeListener> it;
        synchronized (listeners) {
            it = new HashSet<ChangeListener>(listeners).iterator();
        }
        ChangeEvent ev = new ChangeEvent(this);
        while (it.hasNext()) {
            it.next().stateChanged(ev);
        }
    }
    

    // You can use a settings object to keep track of state. Normally the
    // settings object will be the WizardDescriptor, so you can use
    // WizardDescriptor.getProperty & putProperty to store information entered
    // by the user.
    public void readSettings(Object settings) {
        
    }

    public void storeSettings(Object settings) {
        getComponent().storeSettings(getWizardDescriptor());
        java.util.Iterator namesProps = getWizardDescriptor().getProperties().keySet().iterator();
//        while (namesProps.hasNext())
//        {
//            String name = ""+namesProps.next();
//            System.out.println("Property: " + name + " " + getWizardDescriptor().getProperty(name));
//            System.out.flush();
//        }
    }

}
